pub struct HashSetFormer<E, HashSet, Former, ContainerEnd>where
E: Eq + Hash,
HashSet: HashSetLike<E> + Default,
ContainerEnd: Fn(&mut Former, Option<HashSet>),{ /* private fields */ }Expand description
Class for forming hashset-like fields.
Implementations
Sourceimpl<E, HashSet, Former, ContainerEnd> HashSetFormer<E, HashSet, Former, ContainerEnd>where
E: Eq + Hash,
HashSet: HashSetLike<E> + Default,
ContainerEnd: Fn(&mut Former, Option<HashSet>),
impl<E, HashSet, Former, ContainerEnd> HashSetFormer<E, HashSet, Former, ContainerEnd>where
E: Eq + Hash,
HashSet: HashSetLike<E> + Default,
ContainerEnd: Fn(&mut Former, Option<HashSet>),
Sourcepub fn new(
former: Former,
container: Option<HashSet>,
on_end: ContainerEnd,
) -> HashSetFormer<E, HashSet, Former, ContainerEnd>
pub fn new( former: Former, container: Option<HashSet>, on_end: ContainerEnd, ) -> HashSetFormer<E, HashSet, Former, ContainerEnd>
Make a new HashSetFormer. It should be called by a former generated for your structure.
Sourcepub fn replace(
self,
container: HashSet,
) -> HashSetFormer<E, HashSet, Former, ContainerEnd>
pub fn replace( self, container: HashSet, ) -> HashSetFormer<E, HashSet, Former, ContainerEnd>
Set the whole container instead of setting each element individually.
Sourcepub fn end(self) -> Former
pub fn end(self) -> Former
Return former of your struct moving container there. Should be called after configuring the container.
Sourcepub fn insert<E2>(
self,
e: E2,
) -> HashSetFormer<E, HashSet, Former, ContainerEnd>where
E2: Into<E>,
pub fn insert<E2>(
self,
e: E2,
) -> HashSetFormer<E, HashSet, Former, ContainerEnd>where
E2: Into<E>,
Inserts a key-value pair into the map. Make a new container if it was not made so far.