VectorFormer

Struct VectorFormer 

pub struct VectorFormer<E, Vector, Former, ContainerEnd>
where Vector: VectorLike<E> + Debug + PartialEq + Default, ContainerEnd: Fn(&mut Former, Option<Vector>),
{ /* private fields */ }
Class for forming vector-like fields.

Implementations

Source

impl<E, Vector, Former, ContainerEnd> VectorFormer<E, Vector, Former, ContainerEnd>
where Vector: VectorLike<E> + Debug + PartialEq + Default, ContainerEnd: Fn(&mut Former, Option<Vector>),

pub fn new( former: Former, container: Option<Vector>, on_end: ContainerEnd, ) -> VectorFormer<E, Vector, Former, ContainerEnd>

Make a new VectorFormer. It should be called by a former generated for your structure.

pub fn replace( self, vector: Vector, ) -> VectorFormer<E, Vector, Former, ContainerEnd>

Set the whole container instead of setting each element individually.

pub fn end(self) -> Former

Return former of your struct moving container there. Should be called after configuring the container.

pub fn push<E2>(self, e: E2) -> VectorFormer<E, Vector, Former, ContainerEnd>
where E2: Into<E>,

Appends an element to the back of a container. Make a new container if it was not made so far.