pub struct NumBuffer<T>where
T: NumBufferTrait,{ /* private fields */ }🔬This is a nightly-only experimental API. (
int_format_into)Expand description
A buffer wrapper of which the internal size is based on the maximum number of digits the associated integer can have.
Implementations
Sourceimpl<T> NumBuffer<T>where
T: NumBufferTrait,
impl<T> NumBuffer<T>where
T: NumBufferTrait,