HashMapFormer

Struct HashMapFormer 

pub struct HashMapFormer<K, E, HashMap, Former, ContainerEnd>
where K: Eq + Hash, HashMap: HashMapLike<K, E> + Default, ContainerEnd: Fn(&mut Former, Option<HashMap>),
{ /* private fields */ }
Class for forming hashmap-like fields.

Implementations

Source

impl<K, E, HashMap, Former, ContainerEnd> HashMapFormer<K, E, HashMap, Former, ContainerEnd>
where K: Eq + Hash, HashMap: HashMapLike<K, E> + Default, ContainerEnd: Fn(&mut Former, Option<HashMap>),

pub fn new( former: Former, container: Option<HashMap>, on_end: ContainerEnd, ) -> HashMapFormer<K, E, HashMap, Former, ContainerEnd>

Make a new HashMapFormer. It should be called by a former generated for your structure.

pub fn replace( self, container: HashMap, ) -> HashMapFormer<K, E, HashMap, Former, ContainerEnd>

Set the whole container instead of setting each element individually.

pub fn end(self) -> Former

Return former of your struct moving container there. Should be called after configuring the container.

pub fn insert<K2, E2>( self, k: K2, e: E2, ) -> HashMapFormer<K, E, HashMap, Former, ContainerEnd>
where K2: Into<K>, E2: Into<E>,

Inserts a key-value pair into the map. Make a new container if it was not made so far.